@@ -17,16 +17,16 @@ class DateParts(widgets.DateParts):
 
 class ApproximateDateParts(widgets.DateParts):
 
-    _template = 'ApproximateDateParts'
+    template = 'field.ApproximateDateParts'
 
-    def to_request_data(self, schema_type, data):
+    def to_request_data(self, field, data):
         if data is None:
             return {'year': [''], 'month': [''], 'day': ['']}
         parts = [i for i in data.split('-')]
         parts.extend(['']*(3-len(parts)))
         return {'year': [parts[0]], 'month': [parts[1]], 'day': [parts[2]]}
 
-    def from_request_data(self, schema_type, data):
+    def from_request_data(self, field, data):
         # Collect all the parts from the request.
         parts = (data['year'][0].strip(), data['month'][0], data['day'][0])
         if not parts[0] and (parts[1] or parts[2]):
@@ -45,7 +45,7 @@ class ApproximateDateParts(widgets.DateParts):
 
 class ReCAPTCHA(widgets.Input):
 
-    _template = 'ReCAPTCHA'
+    template = 'field.ReCAPTCHA'
 
     API_SSL_SERVER="https://api-secure.recaptcha.net"
     API_SERVER="http://api.recaptcha.net"
@@ -59,12 +59,15 @@ class ReCAPTCHA(widgets.Input):
         self.privatekey = privatekey
         self.remoteip = environ.get('REMOTE_ADDR', '127.0.0.1')
 
-    def pre_parse_request(self, schema_type, request_data, full_request_data):
+    def pre_parse_incoming_request_data(self, field, request_data):
         """ reCaptcha won't let you use your own field names so we move them """
+        full_request_data = field.form.request_data
+        print 'full_request_data',full_request_data
         return {'recaptcha_challenge_field': full_request_data['recaptcha_challenge_field'], 
                 'recaptcha_response_field': full_request_data['recaptcha_response_field'],}
 
-    def from_request_data(self, schema_type, data):
+    def from_request_data(self, field, data):
+        print 'in from ',data
         params = urllib.urlencode({
                         'privatekey': self.privatekey,
                         'remoteip' :  self.remoteip,
@@ -84,7 +87,7 @@ class ReCAPTCHA(widgets.Input):
         response.close()
         return_code = return_values[0]
         if (return_code == "true"):
-            return string_converter(schema_type).to_type('True')
+            return string_converter(field.attr).to_type('True')
         else:
             raise ConvertError('reCAPTCHA failed')
 
