@@ -50,9 +50,7 @@ class TestHTML(unittest.TestCase):
 
         f.add_action('submit', "Submit Me")
         f.defaults = {'one': {'a' : 'ooteenee','c':['3','4','5']}, 'two': {'a': 'opt1','b': date(1966,1,3),'c':['opt2'],'d':'opt2'} } 
-        print '*****'
-        print f()
-        print '*****'
+        f()
         #soup = BeautifulSoup(f())
         ## Latch the results for acceptance tests
         #open('formish/tests/expectations/test_complex_form.html','w').write(html)
@@ -74,8 +72,9 @@ class TestHTML(unittest.TestCase):
         try:
             data = f.validate(r)
         except fv.FormError, e:
-            assert str(f.errors['one']) == 'must be greater than 18; must be greater than 20'
-            assert str(f['one'].field.errors.exceptions[0]) == 'must be greater than 18'
+            print '***',str(f.errors['one'])
+            assert str(f.errors['one']) == 'must be greater than or equal to 18; must be greater than or equal to 20'
+            assert str(f['one'].field.errors.exceptions[0]) == 'must be greater than or equal to 18'
 
     def test_complex_error_all_required_1(self):
         
@@ -92,7 +91,7 @@ class TestHTML(unittest.TestCase):
             data = f.validate(r)
         except fv.FormError, e:
             print '---',f.errors['one']
-            assert str(f.errors['one']) == 'is required; must be greater than 18; must be greater than 20'
+            assert str(f.errors['one']) == 'is required; must be greater than or equal to 18; must be greater than or equal to 20'
             assert str(f['one'].field.errors.exceptions[0]) == 'is required'
 
     def test_complex_error_all_required_2(self):
@@ -109,8 +108,8 @@ class TestHTML(unittest.TestCase):
         try:
             data = f.validate(r)
         except fv.FormError, e:
-            assert str(f.errors['one']) == 'is required; Please fix any of: must be greater than 18; must be greater than 20'
-            assert str(f['one'].field.errors.exceptions[1].exceptions[1]) == 'must be greater than 20'
+            assert str(f.errors['one']) == 'is required; Please fix any of: must be greater than or equal to 18; must be greater than or equal to 20'
+            assert str(f['one'].field.errors.exceptions[1].exceptions[1]) == 'must be greater than or equal to 20'
 
 
 
